@@ -1,5 +1,5 @@
 /* readline.h --- Simple implementation of readline.
-   Copyright (C) 2005, 2009-2020 Free Software Foundation, Inc.
+   Copyright (C) 2005, 2009-2021 Free Software Foundation, Inc.
    Written by Simon Josefsson
 
    This program is free software: you can redistribute it and/or modify
@@ -24,11 +24,13 @@
 # include <stdio.h>
 # include <readline/readline.h>
 #else
+# include <stdlib.h>
 /* Prints a prompt PROMPT and then reads and returns a single line of
    text from the user.  If PROMPT is NULL or the empty string, no
    prompt is displayed.  The returned line is allocated with malloc;
    the caller should free the line when it has finished with it. */
-extern char *readline (const char *prompt);
+extern char *readline (const char *prompt)
+  _GL_ATTRIBUTE_MALLOC _GL_ATTRIBUTE_DEALLOC_FREE;
 #endif
 
 #endif /* GL_READLINE_H */
